pub struct Border<C: Component> {
pub component: C,
pub style: BorderStyle,
}Fields
component: Cstyle: BorderStyleTrait Implementations
Sourceimpl<C: Component> Component for Border<C>
impl<C: Component> Component for Border<C>
Sourcetype Output = <C as Component>::Output
type Output = <C as Component>::Output
The type yielded by the component in response to an event. Typical components only yield
meaningful results when certain conditions have been met (e.g. an item is chosen from a
menu), thus it’s common for this type to be
Option<_>.Sourcetype State = <C as Component>::State
type State = <C as Component>::State
The type of the external state of this component. This allows multiple different components
to share the same piece of state. For components whose entire state is contained within the
component itself, set this to
().Sourcefn render(&self, state: &Self::State, ctx: Ctx<'_>, fb: &mut FrameBuffer)
fn render(&self, state: &Self::State, ctx: Ctx<'_>, fb: &mut FrameBuffer)
Render the component to a frame buffer