pub struct MenuItemIdentifierStatic { /* private fields */ }Trait Implementations
Sourceimpl Component for MenuItemIdentifierStatic
impl Component for MenuItemIdentifierStatic
Sourcetype Output = ()
type Output = ()
The type yielded by the component in response to an event. Typical components only yield
meaningful results when certain conditions have been met (e.g. an item is chosen from a
menu), thus it’s common for this type to be
Option<_>.Sourcetype State = ()
type State = ()
The type of the external state of this component. This allows multiple different components
to share the same piece of state. For components whose entire state is contained within the
component itself, set this to
().Sourcefn render(&self, state: &Self::State, ctx: Ctx<'_>, fb: &mut FrameBuffer)
fn render(&self, state: &Self::State, ctx: Ctx<'_>, fb: &mut FrameBuffer)
Render the component to a frame buffer
Sourceimpl MenuItemIdentifier for MenuItemIdentifierStatic
impl MenuItemIdentifier for MenuItemIdentifierStatic
fn set_selection(&mut self, selection: bool)
fn init_selection(&mut self, selection: bool)